@@ -75,8 +75,8 @@ class ShearGammaPsi(LensProfileBase):
     is as follow:
 
     .. math::
-        \\gamma_1 = \\gamma_{ext} \\cos(2 \\phi_{ext}
-        \\gamma_2 = \\gamma_{ext} \\sin(2 \\phi_{ext}
+        \\gamma_1 = \\gamma_{ext} \\cos(2 \\phi_{ext})
+        \\gamma_2 = \\gamma_{ext} \\sin(2 \\phi_{ext})
 
     """
     param_names = ['gamma_ext', 'psi_ext', 'ra_0', 'dec_0']
@@ -121,7 +121,7 @@ class ShearReduced(LensProfileBase):
     To keep the magnification at unity, it requires
 
     .. math::
-        (1-\\kappa)^2 - \\gamma_1^2 - \\gamma_2^ = 1
+        (1-\\kappa)^2) - \\gamma_1^2 - \\gamma_2^ = 1
 
     Thus, for given pair of reduced shear :math:`(\\gamma'_1, \\gamma'_2)`, an additional convergence term is calculated
     and added to the lensing distortions.
