@@ -1,4 +1,4 @@
-__author__ = 'ewoudwempe'
+__author__ = 'ewoudwempe', 'sibirrer'
 
 import numpy as np
 from lenstronomy.LensModel.Util.epl_util import min_approx, pol_to_cart, cart_to_pol, cdot, ps, rotmat, solvequadeq, brentq_inline
@@ -7,6 +7,7 @@ from lenstronomy.Util.image_util import findOverlap
 from lenstronomy.LensModel.Profiles.epl_numba import alpha, omega
 from lenstronomy.Util.numba_util import jit
 from lenstronomy.Util.param_util import ellipticity2phi_q, shear_cartesian2polar, shear_polar2cartesian
+from lenstronomy.LensModel.Profiles.shear import Shear
 
 
 @jit()
@@ -88,6 +89,7 @@ def _getphi(thpl, args):
     """
     Finds all roots to both versions the 1-dimensional lens equation in phi, by doing a grid search for sign changes on
     the supplied thpl. In the case of extrema, refine at the relevant location.
+
     :param thpl: What points to calculate the equation on use for detecting sign changes
     :param args: Parameters to be passed to the lens equation
     :return: an array containing all roots
@@ -160,9 +162,16 @@ def solvelenseq_majoraxis(args, Nmeas=200, Nmeas_extra=50):
 
 def _check_center(kwargs_lens):
     """Checks if the shear-at-center convention is properly used."""
-    if kwargs_lens[1]['ra_0'] != kwargs_lens[0]['center_x'] or kwargs_lens[1]['dec_0'] != kwargs_lens[0]['center_y']:
-        raise ValueError("Center of lens (center_{x,y}) must be the same as center of shear ({ra,dec}_0). "
-                         "This can be ensured by supplying a dictionary-style joint_setting_list to the model.")
+    # calculate (inverse) displacement caused by the offset between shear and lens centroid
+    # this shift needs to be added to the source position such that the solution of the lens equation
+    # without this shift in the shear is the correct one
+    if len(kwargs_lens) > 1:
+        shear = Shear()
+        # calculate shift from the deflector centroid from the shear field
+        alpha_x, alpha_y = shear.derivatives(kwargs_lens[0]['center_x'], kwargs_lens[0]['center_y'], **kwargs_lens[1])
+        return alpha_x, alpha_y
+    else:
+        return 0, 0
 
 
 def solve_lenseq_pemd(pos_, kwargs_lens, Nmeas=400, Nmeas_extra=80, **kwargs):
@@ -182,14 +191,15 @@ def solve_lenseq_pemd(pos_, kwargs_lens, Nmeas=400, Nmeas_extra=80, **kwargs):
 
     theta_ell, q = ellipticity2phi_q(kwargs_lens[0]['e1'], kwargs_lens[0]['e2'])
     b = kwargs_lens[0]['theta_E']*np.sqrt(q)
-
-    cen = kwargs_lens[0]['center_x']+1j*kwargs_lens[0]['center_y']
-    p = pos[0]+1j*pos[1]-cen
     if len(kwargs_lens) > 1:
         gamma = kwargs_lens[1]['gamma1']+1j*kwargs_lens[1]['gamma2']
-        _check_center(kwargs_lens)
     else:
         gamma = 0+0j
+    shift_x, shift_y = _check_center(kwargs_lens)
+    shift = shift_x + 1j * shift_y
+    cen = kwargs_lens[0]['center_x']+1j*kwargs_lens[0]['center_y']
+    p = pos[0]+1j*pos[1] - cen + shift
+
     rotfact = np.exp(-1j*theta_ell)
     gamma *= rotfact**2
     p *= rotfact
@@ -218,7 +228,6 @@ def caustics_epl_shear(kwargs_lens, num_th=500, maginf=0, sourceplane=True, retu
         gamma1unr, gamma2unr = kwargs_lens[1]['gamma1'], kwargs_lens[1]['gamma2']
     else:
         gamma1unr, gamma2unr = 0, 0
-    _check_center(kwargs_lens)
     t = kwargs_lens[0]['gamma']-1 if 'gamma' in kwargs_lens[0] else 1
     theta_ell, q = ellipticity2phi_q(e1, e2)
     theta_gamma, gamma_mag = shear_cartesian2polar(gamma1unr, gamma2unr)
