@@ -100,7 +100,7 @@ class LensEquationSolver(object):
         absmapped = util.displaceAbs(x_mapped, y_mapped, sourcePos_x, sourcePos_y)
         # select minima in the grid points and select grid points that do not deviate more than the
         # width of the grid point to a solution of the lens equation
-        x_mins, y_mins, delta_map = util.neighborSelect(absmapped, x_grid, y_grid)
+        x_mins, y_mins, delta_map = util.local_minima_2d(absmapped, x_grid, y_grid)
         # pixel width
         pixel_width = x_grid[1]-x_grid[0] 
             
@@ -124,7 +124,7 @@ class LensEquationSolver(object):
         """
         lens_model_list = list(self.lensModel.lens_model_list)
         if lens_model_list not in (['SIE', 'SHEAR'], ['SIE'], ['EPL_NUMBA', 'SHEAR'], ['EPL_NUMBA'], ['EPL', 'SHEAR'], ['EPL']):
-            raise ValueError("Only SIE or PEMD (+shear) supported in the analytical solver for now")
+            raise ValueError("Only SIE, EPL, EPL_NUMBA (+shear) supported in the analytical solver for now.")
 
         x_mins, y_mins = solve_lenseq_pemd((x, y), kwargs_lens, **kwargs_solver)
         if arrival_time_sort:
@@ -189,7 +189,8 @@ class LensEquationSolver(object):
         # pixel width
         x_mins, y_mins, delta_map, pixel_width = self.candidate_solutions(sourcePos_x, sourcePos_y, kwargs_lens, min_distance, search_window, verbose, x_center, y_center)
         if verbose:
-            print("There are %s regions identified that could contain a solution of the lens equation" % len(x_mins))
+            print("There are %s regions identified that could contain a solution of the lens equation with"
+                  "coordinates %s and %s " % (len(x_mins), x_mins, y_mins))
         if len(x_mins) < 1:
             return x_mins, y_mins
         if initial_guess_cut:
