@@ -300,9 +300,7 @@ class UpdateManager(object):
         if special_add_fixed is None:
             special_add_fixed = []
         for param_name in special_add_fixed:
-            if param_name in special_fixed:
-                pass
-            else:
+            if param_name not in special_fixed:
                 special_fixed[param_name] = special_temp[param_name]
         if special_remove_fixed is None:
             special_remove_fixed = []
