@@ -1,5 +1,5 @@
-__author__ = 'Simon Birrer and contributors'
-__email__ = 'sibirrer@gmail.com'
+__author__ = 'lenstronomy developers'
+__email__ = 'lenstronomy-dev@googlegroups.com'
 __version__ = '1.10.4'
 __credits__ = 'ETH Zurich, UCLA, Stanford, Stony Brook'
 
