@@ -72,8 +72,9 @@ class TestCompare(object):
 class TestInvertCosmo(object):
     def setup(self):
         self.z_d, self.z_s = 0.295, 0.658
-        self.invertCosmo = InvertCosmo(z_d=self.z_d, z_s=self.z_s, H0_range=np.linspace(10, 100, 20),
-                                       omega_m_range=np.linspace(0.05, 1, 20))
+        self.invertCosmo = InvertCosmo(z_d=self.z_d, z_s=self.z_s, H0_range=np.linspace(10, 100, 50),
+                                       omega_m_range=np.linspace(0.05, 1, 50))
+        self.invertCosmo_default = InvertCosmo(z_d=self.z_d, z_s=self.z_s)
 
     def test_get_cosmo(self):
         H0 = 80
@@ -83,6 +84,10 @@ class TestInvertCosmo(object):
         npt.assert_almost_equal(H0_new, H0, decimal=1)
         npt.assert_almost_equal(omega_m_new, omega_m, decimal=3)
 
+        H0_new, omega_m_new = self.invertCosmo_default.get_cosmo(Dd, Ds_Dds)
+        npt.assert_almost_equal(H0_new, H0, decimal=1)
+        npt.assert_almost_equal(omega_m_new, omega_m, decimal=3)
+
         H0_new, omega_m_new = self.invertCosmo.get_cosmo(Dd=1, Ds_Dds=1)
         assert H0_new == -1
 
