@@ -38,13 +38,14 @@ class TestGaussianKappa(object):
         center_x = 0.
         center_y = 0.
         sigma = [1.]
-        f_xx, f_yy, f_xy = self.gaussian_kappa.hessian(x, y, amp, sigma, center_x, center_y)
+        f_xx, f_xy, f_yx, f_yy = self.gaussian_kappa.hessian(x, y, amp, sigma, center_x, center_y)
         kappa = 1./2 * (f_xx + f_yy)
         kappa_true = self.gaussian.function(x, y, amp[0], sigma[0], center_x, center_y)
         print(kappa_true)
         print(kappa)
         npt.assert_almost_equal(kappa[0], kappa_true[0], decimal=5)
         npt.assert_almost_equal(kappa[1], kappa_true[1], decimal=5)
+        npt.assert_almost_equal(f_xy, f_yx, decimal=8)
 
     def test_density_2d(self):
         x = np.linspace(0, 5, 10)
@@ -53,7 +54,7 @@ class TestGaussianKappa(object):
         center_x = 0.
         center_y = 0.
         sigma = [1.]
-        f_xx, f_yy, f_xy = self.gaussian_kappa.hessian(x, y, amp, sigma, center_x, center_y)
+        f_xx, f_xy, f_yx, f_yy = self.gaussian_kappa.hessian(x, y, amp, sigma, center_x, center_y)
         kappa = 1./2 * (f_xx + f_yy)
         amp_3d = self.g_kappa._amp2d_to_3d(amp, sigma[0], sigma[0])
         density_2d = self.gaussian_kappa.density_2d(x, y, amp_3d, sigma, center_x, center_y)
@@ -103,11 +104,12 @@ class TestGaussianKappaEllipse(object):
         sigma = 1
         e1, e2 = 0.1, -0.1
         center_x, center_y = 1, 0
-        f_xx, f_yy, f_xy = self.multi.hessian(x, y, amp=[amp], sigma=[sigma], e1=e1, e2=e2, center_x=center_x, center_y=center_y)
-        f_xx_s, f_yy_s, f_xy_s = self.single.hessian(x, y, amp=amp, sigma=sigma, e1=e1, e2=e2, center_x=center_x, center_y=center_y)
+        f_xx, f_xy, f_yx, f_yy = self.multi.hessian(x, y, amp=[amp], sigma=[sigma], e1=e1, e2=e2, center_x=center_x, center_y=center_y)
+        f_xx_s, f_xy_s, f_yx_s, f_yy_s = self.single.hessian(x, y, amp=amp, sigma=sigma, e1=e1, e2=e2, center_x=center_x, center_y=center_y)
         npt.assert_almost_equal(f_xx, f_xx_s, decimal=8)
         npt.assert_almost_equal(f_yy, f_yy_s, decimal=8)
         npt.assert_almost_equal(f_xy, f_xy_s, decimal=8)
+        npt.assert_almost_equal(f_yx, f_yx_s, decimal=7)
 
     def test_density_2d(self):
         x, y = 1, 2
@@ -130,4 +132,4 @@ class TestGaussianKappaEllipse(object):
 
 
 if __name__ == '__main__':
-    pytest.main()
\ No newline at end of file
+    pytest.main()
