@@ -22,14 +22,14 @@ class TestCartShapelets(object):
         beta = 1.
         coeffs = (1., 1.)
         values = self.cartShapelets.function(x, y, coeffs, beta)
-        assert values[0] == 0.11180585426466891
+        npt.assert_almost_equal(values[0], 0.11180585426466888, decimal=9)
 
         x = 1.
         y = 2.
         beta = 1.
         coeffs = (1., 1.)
         values = self.cartShapelets.function(x, y, coeffs, beta)
-        assert values == 0.11180585426466891
+        npt.assert_almost_equal(values, 0.11180585426466891, decimal=9)
 
         x = np.array([0])
         y = np.array([0])
@@ -40,11 +40,11 @@ class TestCartShapelets(object):
 
         coeffs = (1, 1., 0, 0, 1, 1)
         values = self.cartShapelets.function(x, y, coeffs, beta)
-        assert values[0] == 0.16524730314632363
+        npt.assert_almost_equal(values[0], 0.16524730314632363, decimal=9)
 
         coeffs = (1, 1., 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0)
         values = self.cartShapelets.function(x, y, coeffs, beta)
-        assert values[0] == 0.16524730314632363
+        npt.assert_almost_equal(values[0], 0.16524730314632363, decimal=9)
 
         coeffs = (0., 0., 0, 0, 0., 0., 0, 0, 0, 0, 0, 0, 0, 0, 0)
         values = self.cartShapelets.function(x, y, coeffs, beta)
