@@ -428,6 +428,16 @@ class TestNumericsProfile(object):
         lens_model = ['SPL_CORE']
         self.assert_differentials(lens_model, kwargs, potential=False)
 
+    def test_gnfw(self):
+
+        kwargs = {'alpha_Rs': 1.2, 'Rs': 0.8, 'gamma_inner': 2.3, 'gamma_outer': 3.15}
+        lens_model = ['GNFW']
+        self.assert_differentials(lens_model, kwargs, potential=False)
+
+        kwargs = {'alpha_Rs': 1.2, 'Rs': 0.8, 'gamma_inner': 0.3, 'gamma_outer': 3.15}
+        lens_model = ['GNFW']
+        self.assert_differentials(lens_model, kwargs, potential=False)
+
     def test_cse(self):
         kwargs = {'a': 2, 's': 1., 'e1': 0, 'e2': 0, 'center_x': 0., 'center_y': 0.}
         lens_model = ['CSE']
@@ -471,6 +481,5 @@ class TestNumericsProfile(object):
         lens_model = ['HERNQUIST_ELLIPSE_CSE']
         self.assert_differentials(lens_model, kwargs, potential=True)
 
-
 if __name__ == '__main__':
     pytest.main("-k TestLensModel")
