@@ -39,7 +39,7 @@ class TestNumerics(object):
         mass_3d = lensModel.mass_3d(r, **kwargs)
         npt.assert_almost_equal(mass_3d/mass_3d_num, 1, decimal=2)
 
-    def assert_lens_integrals(self, Model, kwargs):
+    def assert_lens_integrals(self, Model, kwargs, pi_convention=True):
         """
         checks whether the integral in projection of the density_lens() function is the convergence
 
@@ -54,23 +54,30 @@ class TestNumerics(object):
         f_xx, f_xy, f_yx, f_yy = lensModel.hessian(r, 0, **kwargs)
         kappa = 1./2 * (f_xx + f_yy)
         npt.assert_almost_equal(kappa_num, kappa, decimal=2)
-        if hasattr(lensModel, 'mass_2d_lens'):
-            try:
-                del kwargs['center_x']
-                del kwargs['center_y']
-            except:
-                pass
+        try:
+            del kwargs['center_x']
+            del kwargs['center_y']
+        except:
+            pass
+        bool_mass_2d_lens = False
+        try:
             mass_2d = lensModel.mass_2d_lens(r, **kwargs)
+            bool_mass_2d_lens = True
+        except:
+            pass
+        if bool_mass_2d_lens:
             alpha_x, alpha_y = lensModel.derivatives(r, 0, **kwargs)
-            alpha = np.sqrt(alpha_x**2 + alpha_y**2)
-            npt.assert_almost_equal(alpha, mass_2d/ r / np.pi, decimal=5)
-        if hasattr(lensModel, 'mass_3d_lens'):
-            try:
-                del kwargs['center_x']
-                del kwargs['center_y']
-            except:
-                pass
+            alpha = np.sqrt(alpha_x ** 2 + alpha_y ** 2)
+            if pi_convention:
+                npt.assert_almost_equal(alpha, mass_2d / r / np.pi, decimal=5)
+            else:
+                npt.assert_almost_equal(alpha, mass_2d / r, decimal=5)
+        try:
             mass_3d = lensModel.mass_3d_lens(r, **kwargs)
+            bool_mass_3d_lens = True
+        except:
+            bool_mass_3d_lens = False
+        if bool_mass_3d_lens:
             mass_3d_num = int_profile.mass_enclosed_3d(r, kwargs_profile=kwargs, lens_param=True)
             print(mass_3d, mass_3d_num, 'test num')
             npt.assert_almost_equal(mass_3d / mass_3d_num, 1, decimal=2)
@@ -98,7 +105,7 @@ class TestNumerics(object):
         mass_2d = lensModel.mass_2d(r, **kwargs_density)
         alpha_mass = mass_2d/r
         alpha_r, _ = lensModel.derivatives(r, 0, **kwargs_lens)
-        npt.assert_almost_equal(alpha_mass/np.pi, alpha_r, decimal=5)
+        npt.assert_almost_equal(alpha_mass / np.pi, alpha_r, decimal=5)
 
     def test_nfw(self):
         kwargs = {'rho0': 1.,  'Rs': 5., 'center_x': 0, 'center_y': 0}
@@ -129,11 +136,13 @@ class TestNumerics(object):
         rho0 = lensModel.alpha2rho0(alpha_Rs, Rs)
         kwargs_lens = {'alpha_Rs': alpha_Rs, 'Rs': Rs}
         kwargs_density = {'rho0': rho0, 'Rs': Rs}
+        self.assert_lens_integrals(Model, kwargs_lens)
+        self.assert_integrals(Model, kwargs_density)
         r = 2.
         mass_2d = lensModel.mass_2d(r, **kwargs_density)
         alpha_mass = mass_2d/r
         alpha_r, _ = lensModel.derivatives(r, 0, **kwargs_lens)
-        npt.assert_almost_equal(alpha_mass/np.pi, alpha_r, decimal=5)
+        npt.assert_almost_equal(alpha_mass / np.pi, alpha_r, decimal=5)
 
     def test_hernquist(self):
         from lenstronomy.LensModel.Profiles.hernquist import Hernquist as Model
@@ -166,14 +175,14 @@ class TestNumerics(object):
         mass_2d = lensModel.mass_2d(r, **kwargs_density)
         alpha_mass = mass_2d/r
         alpha_r, _ = lensModel.derivatives(r, 0, **kwargs_lens)
-        npt.assert_almost_equal(alpha_mass/np.pi, alpha_r, decimal=5)
+        npt.assert_almost_equal(alpha_mass / np.pi, alpha_r, decimal=5)
 
     def test_sis(self):
         from lenstronomy.LensModel.Profiles.sis import SIS as Model
         kwargs = {'rho0': 1.}
         self.assert_integrals(Model, kwargs)
         kwargs_lens = {'theta_E': 1.}
-        self.assert_lens_integrals(Model, kwargs_lens)
+        self.assert_lens_integrals(Model, kwargs_lens, pi_convention=True)
 
     def test_sis_density_deflection(self):
         """
@@ -191,7 +200,7 @@ class TestNumerics(object):
         mass_2d = lensModel.mass_2d(r, **kwargs_density)
         alpha_mass = mass_2d/r
         alpha_r, _ = lensModel.derivatives(r, 0, **kwargs_lens)
-        npt.assert_almost_equal(alpha_mass/np.pi, alpha_r, decimal=5)
+        npt.assert_almost_equal(alpha_mass / np.pi, alpha_r, decimal=5)
         lensModel.density_2d(1, 1, rho0=1)
 
     def test_sie(self):
@@ -222,7 +231,7 @@ class TestNumerics(object):
         mass_2d = lensModel.mass_2d(r, **kwargs_density)
         alpha_mass = mass_2d/r
         alpha_r, _ = lensModel.derivatives(r, 0, **kwargs_lens)
-        npt.assert_almost_equal(alpha_mass/np.pi, alpha_r, decimal=5)
+        npt.assert_almost_equal(alpha_mass / np.pi, alpha_r, decimal=5)
 
     def test_spp(self):
         from lenstronomy.LensModel.Profiles.spp import SPP as Model
@@ -251,7 +260,7 @@ class TestNumerics(object):
         mass_2d = lensModel.mass_2d(r, **kwargs_density)
         alpha_mass = mass_2d/r
         alpha_r, _ = lensModel.derivatives(r, 0, **kwargs_lens)
-        npt.assert_almost_equal(alpha_mass/np.pi, alpha_r, decimal=5)
+        npt.assert_almost_equal(alpha_mass / np.pi, alpha_r, decimal=5)
 
     def test_gaussian(self):
         from lenstronomy.LensModel.Profiles.gaussian_kappa import GaussianKappa as Model
@@ -275,7 +284,7 @@ class TestNumerics(object):
         mass_2d = lensModel.mass_2d(r, **kwargs_density)
         alpha_mass = mass_2d/r
         alpha_r, _ = lensModel.derivatives(r, 0, **kwargs_lens)
-        npt.assert_almost_equal(alpha_mass/np.pi, alpha_r, decimal=5)
+        npt.assert_almost_equal(alpha_mass / np.pi, alpha_r, decimal=5)
 
     def test_coreBurk(self):
         from lenstronomy.LensModel.Profiles.coreBurkert import CoreBurkert as Model
@@ -367,6 +376,16 @@ class TestNumerics(object):
                   'w_c3': 2, 'w_t3': 5, 'e13': 0, 'e23': 0}
         self.assert_lens_integrals(Model, kwargs)
 
+    def test_gnfw(self):
+
+        from lenstronomy.LensModel.Profiles.general_nfw import GNFW as Model
+        kwargs = {'alpha_Rs': 0.7, 'Rs': 0.3, 'gamma_inner': 1., 'gamma_outer': 3.2}
+        self.assert_lens_integrals(Model, kwargs)
+        kwargs = {'alpha_Rs': 0.7, 'Rs': 0.3, 'gamma_inner': 2.5, 'gamma_outer': 3.0}
+        self.assert_lens_integrals(Model, kwargs)
+        kwargs = {'alpha_Rs': 0.7, 'Rs': 0.3, 'gamma_inner': 0.5, 'gamma_outer': 2.6}
+        self.assert_lens_integrals(Model, kwargs)
+
 
     """
     def test_sis(self):
@@ -381,6 +400,5 @@ class TestNumerics(object):
 
     """
 
-
 if __name__ == '__main__':
     pytest.main("-k TestLensModel")
