@@ -53,7 +53,7 @@ class TestPlotUtil(object):
     def test_cmap_conf(self):
         cmap = plot_util.cmap_conf(cmap_string='gist_heat')
         cmap_update = plot_util.cmap_conf(cmap_string=cmap)
-        assert cmap is cmap_update
+        assert cmap.name == cmap_update.name
 
     def test_plot_line_set(self):
 
