@@ -1,11 +1,8 @@
-__author__ = 'aymgal'
 
 import copy
 
 import pytest
-import numpy as np
 from numpy.testing import assert_raises
-import numpy.testing as npt
 
 from lenstronomy.Sampling.Samplers.nautilus import Nautilus
 
@@ -14,7 +11,7 @@ from lenstronomy.Sampling.Samplers.nautilus import Nautilus
 def import_fixture(simple_einstein_ring_likelihood_2d):
     """
 
-    :param simple_einstein_ring_likelihood: fixture
+    :param simple_einstein_ring_likelihood_2d: fixture
     :return:
     """
     likelihood, kwargs_truths = simple_einstein_ring_likelihood_2d
@@ -43,11 +40,22 @@ class TestNautilusSampler(object):
         }
         points, log_w, log_l, log_z = sampler.nautilus_sampling(**kwargs_run)
         assert len(points) == 100
+        assert len(log_l) == 100
 
         kwargs_run_fail = copy.deepcopy(kwargs_run)
         kwargs_run_fail['prior_type'] = 'wrong'
         assert_raises(ValueError, sampler.nautilus_sampling, **kwargs_run_fail)
 
+    def test_prior(self):
+
+        num_param = 10
+        from nautilus import Prior
+        prior = Prior()
+
+        for i in range(num_param):
+            prior.add_parameter(dist=(0, 1))
+        assert num_param == prior.dimensionality()
+
 
 if __name__ == '__main__':
     pytest.main()
