@@ -110,16 +110,35 @@ class TestSampler(object):
         # 1) run a chain specifiying a backup file name
         backup_filename = 'test_mcmc_emcee.h5'
         samples_1, dist_1 = self.sampler.mcmc_emcee(n_walkers, n_run, n_burn, mean_start, sigma_start, mpi=False,
-                                                    backup_filename=backup_filename)
+                                                    backend_filename=backup_filename)
         assert len(samples_1) == n_walkers * n_run
         # 2) run a chain starting from the backup of previous run
         samples_2, dist_2 = self.sampler.mcmc_emcee(n_walkers, n_run, n_burn, mean_start, sigma_start, mpi=False,
-                                                    backup_filename=backup_filename, start_from_backup=True)
+                                                    backend_filename=backup_filename, start_from_backend=True)
         assert len(samples_2) == len(samples_1) + n_walkers * n_run
         assert len(dist_2) == len(samples_2)
-        
+
         os.remove(backup_filename)  # just remove the backup file created above
 
+    def test_mcmc_zeus(self):
+        n_walkers = 36
+        n_run = 2
+        n_burn = 2
+        mean_start = self.param_class.kwargs2args(kwargs_lens=self.kwargs_lens, kwargs_source=self.kwargs_source,
+                                                  kwargs_lens_light=self.kwargs_lens_light)
+        sigma_start = np.ones_like(mean_start) * 0.1
+        samples, dist = self.sampler.mcmc_zeus(n_walkers, n_run, n_burn, mean_start, sigma_start)
+        assert len(samples) == n_walkers * n_run
+        assert len(dist) == len(samples)
+
+        # test of backup file
+        backup_filename = 'test_mcmc_zeus.h5'
+        samples_1, dist_1 = self.sampler.mcmc_zeus(n_walkers, n_run, n_burn, mean_start, sigma_start,
+                                                    backend_filename=backup_filename)
+        assert len(samples_1) == n_walkers * n_run
+
+        os.remove(backup_filename)
+
 
 if __name__ == '__main__':
     pytest.main()
