@@ -322,11 +322,22 @@ def test_min_square_dist():
     assert dist[1] == 1
 
 
+def test_neighbor_select_fast():
+    a = np.ones(100)
+    a[41] = 0
+    x = np.linspace(0, 99, 100)
+    y = np.linspace(0, 99, 100)
+    x_mins, y_mins, values = util.local_minima_2d(a, x, y)
+    assert x_mins[0] == 41
+    assert y_mins[0] == 41
+    assert values[0] == 0
+
+
 def test_neighborSelect():
     a = np.ones(100)
     a[41] = 0
-    x = np.linspace(0,99,100)
-    y = np.linspace(0,99,100)
+    x = np.linspace(0, 99, 100)
+    y = np.linspace(0, 99, 100)
     x_mins, y_mins, values = util.neighborSelect(a, x, y)
     assert x_mins[0] == 41
     assert y_mins[0] == 41
